@@ -5,7 +5,8 @@ from etcaetera.utils import format_key
 class Overrides(Adapter):
     def __init__(self, data={}, *args, **kwargs):
         super(Overrides, self).__init__(*args, **kwargs)
-        self.data = {format_key(k):v for k,v in data.items()}
+        self.data = data
+        self.load()
 
-    def load(self):
-        pass
+    def load(self, formatter=None):
+        self.data = {self.format(k, formatter): v for k, v in self.data.items()}
